==> cscec5b-dataexchange-api-3.0.1-20211009.103740-1-sources.jar: com/ejianc/business/dataexchange/vo/CmContract.java <==
package com.ejianc.business.dataexchange.vo;

/**
 * 五局合同 实体
 * @author Brin
 * @since 2020-10-30 11:50:23
 */

public class CmContract {

    private static final long serialVersionUID = 1L;
    
    private java.lang.String pkContract;
    private java.lang.String pkProject;
    private java.lang.String contractcode;
    private java.lang.String contractname;
    private java.lang.String contractA;
    private java.lang.String pkFirstbase;
    private java.lang.String custname;
    private java.lang.String contractB;
    private java.lang.String pkSupplier;
    private java.lang.String suppliername;
    private java.lang.Integer icontstatus;
    private java.lang.String contractStatus;
    private java.lang.String pkCorp;
    private java.lang.String billtypename;

    public String getBilltypename() {
        return billtypename;
    }

    public void setBilltypename(String billtypename) {
        this.billtypename = billtypename;
    }

    public String getPkCorp() {
        return pkCorp;
    }

    public void setPkCorp(String pkCorp) {
        this.pkCorp = pkCorp;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getContractcode() {
        return contractcode;
    }

    public void setContractcode(String contractcode) {
        this.contractcode = contractcode;
    }

    public String getContractname() {
        return contractname;
    }

    public void setContractname(String contractname) {
        this.contractname = contractname;
    }

    public String getContractA() {
        return contractA;
    }

    public void setContractA(String contractA) {
        this.contractA = contractA;
    }

    public String getPkFirstbase() {
        return pkFirstbase;
    }

    public void setPkFirstbase(String pkFirstbase) {
        this.pkFirstbase = pkFirstbase;
    }

    public String getCustname() {
        return custname;
    }

    public void setCustname(String custname) {
        this.custname = custname;
    }

    public String getContractB() {
        return contractB;
    }

    public void setContractB(String contractB) {
        this.contractB = contractB;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }

    public Integer getIcontstatus() {
        return icontstatus;
    }

    public void setIcontstatus(Integer icontstatus) {
        this.icontstatus = icontstatus;
    }

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }
}

==> cscec5b-dataexchange-api-3.0.1-20211105.081514-6-sources.jar: com/ejianc/business/dataexchange/vo/CmContract.java <==
package com.ejianc.business.dataexchange.vo;

/**
 * 五局合同 实体
 * @author Brin
 * @since 2020-10-30 11:50:23
 */

public class CmContract {

    private static final long serialVersionUID = 1L;
    
    private java.lang.String pkContract;
    private java.lang.String pkProject;
    private java.lang.String contractcode;
    private java.lang.String contractname;
    private java.lang.String contractA;
    private java.lang.String pkFirstbase;
    private java.lang.String custname;
    private java.lang.String contractB;
    private java.lang.String pkSupplier;
    private java.lang.String suppliername;
    private java.lang.Integer icontstatus;
    private java.lang.String contractStatus;
    private java.lang.String pkCorp;
    private java.lang.String billtypename;
    private java.lang.String pkCtManage;

    public String getBilltypename() {
        return billtypename;
    }

    public void setBilltypename(String billtypename) {
        this.billtypename = billtypename;
    }

    public String getPkCorp() {
        return pkCorp;
    }

    public void setPkCorp(String pkCorp) {
        this.pkCorp = pkCorp;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getPkProject() {
        return pkProject;
    }

    public void setPkProject(String pkProject) {
        this.pkProject = pkProject;
    }

    public String getContractcode() {
        return contractcode;
    }

    public void setContractcode(String contractcode) {
        this.contractcode = contractcode;
    }

    public String getContractname() {
        return contractname;
    }

    public void setContractname(String contractname) {
        this.contractname = contractname;
    }

    public String getContractA() {
        return contractA;
    }

    public void setContractA(String contractA) {
        this.contractA = contractA;
    }

    public String getPkFirstbase() {
        return pkFirstbase;
    }

    public void setPkFirstbase(String pkFirstbase) {
        this.pkFirstbase = pkFirstbase;
    }

    public String getCustname() {
        return custname;
    }

    public void setCustname(String custname) {
        this.custname = custname;
    }

    public String getContractB() {
        return contractB;
    }

    public void setContractB(String contractB) {
        this.contractB = contractB;
    }

    public String getPkSupplier() {
        return pkSupplier;
    }

    public void setPkSupplier(String pkSupplier) {
        this.pkSupplier = pkSupplier;
    }

    public String getSuppliername() {
        return suppliername;
    }

    public void setSuppliername(String suppliername) {
        this.suppliername = suppliername;
    }

    public Integer getIcontstatus() {
        return icontstatus;
    }

    public void setIcontstatus(Integer icontstatus) {
        this.icontstatus = icontstatus;
    }

    public String getContractStatus() {
        return contractStatus;
    }

    public void setContractStatus(String contractStatus) {
        this.contractStatus = contractStatus;
    }

    public String getPkCtManage() {
        return pkCtManage;
    }

    public void setPkCtManage(String pkCtManage) {
        this.pkCtManage = pkCtManage;
    }
}
